//
// StarCalendar.java -- display positions of Saturn and its moons.
//	Copyright 2002 by Akkana Peck.
// You may use or distribute this code under the terms of the GPL.
//

package Akk.Astro;

//import java.util.Date;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

public class StarCalendar extends Panel
    implements ItemListener
{
    StarDate date;
    ActionListener parentListener;
    Choice chMonth, chDay, chYear, chHour, chMin;
    Label tzLabl;

    public StarCalendar(EventListener listener)
    {
        parentListener = (ActionListener)listener;
        buildUI();
        setDate(new StarDate());
    }

    public StarCalendar(EventListener listener, Date d)
    {
        parentListener = (ActionListener)listener;
        buildUI();
        setDate(d);
    }

    void buildUI()
    {
	setLayout(new GridLayout(2, 1));

        Panel row = new Panel();
	row.setLayout(new FlowLayout(FlowLayout.LEFT));
        chMonth = new Choice();
        chMonth.setName("month");
        chMonth.add("Jan");
        chMonth.add("Feb");
        chMonth.add("Mar");
        chMonth.add("Apr");
        chMonth.add("May");
        chMonth.add("Jun");
        chMonth.add("Jul");
        chMonth.add("Aug");
        chMonth.add("Sep");
        chMonth.add("Oct");
        chMonth.add("Nov");
        chMonth.add("Dec");
        chMonth.select(9);
        chMonth.addItemListener(this);
        row.add(chMonth);

        chDay = new Choice();
        chDay.setName("day");
        for (int day = 1; day <= 31; ++day)
            chDay.add(Integer.toString(day));
        chDay.addItemListener(this);
        row.add(chDay);

        chYear = new Choice();
        chYear.setName("year");
        chYear.add("2001");
        chYear.add("2002");
        chYear.add("2003");
        chYear.add("2004");
        chYear.select("2002");
        chYear.addItemListener(this);
        row.add(chYear);

        add(row);

        //
        // Start second row
        //
        row = new Panel();
	row.setLayout(new FlowLayout(FlowLayout.LEFT));

        chHour = new Choice();
        chHour.setName("hour");
        for (int hour = 0; hour < 24; ++hour)
            chHour.add(Integer.toString(hour));
        chHour.addItemListener(this);
        row.add(chHour);

        chMin = new Choice();
        chMin.setName("minute");
        chMin.add("00");
        chMin.add("15");
        chMin.add("30");
        chMin.add("45");
        chMin.addItemListener(this);
        row.add(chMin);

        tzLabl = new Label(new String("UT    "));
        row.add(tzLabl);

        add(row);
    }

    public void itemStateChanged(ItemEvent e)
    {
        //System.out.println("StarCalendar item changed: "
        //                   + ((Component)(e.getItemSelectable())).getName()
        //                   + " = "
        //                   + e.getItem().toString()
        //                  );
        setFromUI();
        if (parentListener != null)
        {
            ActionEvent ev = new ActionEvent(this, e.getID(),
                                             new String("dateChanged"));
            parentListener.actionPerformed(ev);
        }
    }

    void setFromUI()
    {
        if (date == null)
            date = new StarDate();
        date.setYear(Integer.parseInt(chYear.getSelectedItem()) - 1900);
        date.setMonth(chMonth.getSelectedIndex());
        date.setDate(chDay.getSelectedIndex() + 1);
        date.setHours(chHour.getSelectedIndex());
        date.setMinutes(Integer.parseInt(chMin.getSelectedItem()));
        date.setSeconds(0);
    }

    void setUIFromDate()
    {
        if (date == null)
            date = new StarDate();
        chMonth.select(date.getMonth());
        chDay.select(date.getDate()-1);
        chYear.select(Integer.toString(date.getYear()));
        chHour.select(Integer.toString(date.getHours()));
        int min15 = ((date.getMinutes()%60) + 7) / 15;
        String minS = Integer.toString(min15 * 15);
        if (minS.length() == 1)
            minS = "0" + minS;
        chMin.select(minS);
        int tz = date.getTimezoneOffset();
        String tzstr = new String("UT");
        // stupid Date class has the timezone offset sign backward ...
        if (tz > 0)
            tzstr += Float.toString(-tz/60);
        else if (tz < 0)
            tzstr += new String("+") + Float.toString(-tz/60);
        tzLabl.setText(tzstr);
    }

    public void setJulianDate(double jd)
    {
    }

    public void setDate(Date d)
    {
        date = new StarDate(d);
        setUIFromDate();
    }

    public StarDate getDate()
    {
        return date;
    }
}

